@@ -1,4 +1,4 @@
-# SPDX-License-Identifier: EUPL-1.2
+# SPDX-License-Identifier: MIT
 # SPDX-FileCopyrightText: 2021 Quansight, LLC
 # SPDX-FileCopyrightText: 2021 Filipe Laíns <lains@riseup.net>
 
@@ -47,7 +47,7 @@ def create_targz(path: Path) -> Iterator[Tuple[tarfile.TarFile, Optional[int]]]:
     mtime = int(source_date_epoch) if source_date_epoch else None
 
     file = typing.cast(IO[bytes], gzip.GzipFile(
-        os.path.join(path, path),
+        path,
         mode='wb',
         mtime=mtime,
     ))
