@@ -1,6 +1,8 @@
 # SPDX-License-Identifier: MIT
 
 import os
+import stat
+import sys
 import tarfile
 import textwrap
 
@@ -70,18 +72,32 @@ def test_contents_unstaged(package_pure, tmpdir):
     assert read_data == new_data.encode()
 
 
-@pytest.mark.skipif(os.name == 'nt', reason='Executable bit does not exist on Windows')
+@pytest.mark.skipif(sys.platform in {'win32', 'cygwin'}, reason='Platform does not support executable bit')
 def test_executable_bit(sdist_executable_bit):
     sdist = tarfile.open(sdist_executable_bit, 'r:gz')
 
-    assert set((tar.name, tar.mode) for tar in sdist.getmembers()) == {
-        ('executable_bit-1.0.0/PKG-INFO', 420),
-        # We match the executable bit on everything
-        # but PKG-INFO(we create this ourselves)
-        # Note: File perms are in octal, but Python returns it in int
-        ('executable_bit-1.0.0/example-script.py', int('755', 8)),
-        ('executable_bit-1.0.0/example.c', int('644', 8)),
-        ('executable_bit-1.0.0/executable_module.py', int('755', 8)),
-        ('executable_bit-1.0.0/meson.build', int('644', 8)),
-        ('executable_bit-1.0.0/pyproject.toml', int('644', 8)),
+    expected = {
+        'executable_bit-1.0.0/PKG-INFO': False,
+        'executable_bit-1.0.0/example-script.py': True,
+        'executable_bit-1.0.0/example.c': False,
+        'executable_bit-1.0.0/executable_module.py': True,
+        'executable_bit-1.0.0/meson.build': False,
+        'executable_bit-1.0.0/pyproject.toml': False,
     }
+    for member in sdist.getmembers():
+        assert bool(member.mode & stat.S_IXUSR) == expected[member.name]
+
+
+def test_generated_files(sdist_generated_files):
+    sdist = tarfile.open(sdist_generated_files, 'r:gz')
+    expected = {
+        'executable_bit-1.0.0/PKG-INFO',
+        'executable_bit-1.0.0/example-script.py',
+        'executable_bit-1.0.0/example.c',
+        'executable_bit-1.0.0/executable_module.py',
+        'executable_bit-1.0.0/meson.build',
+        'executable_bit-1.0.0/pyproject.toml',
+        'executable_bit-1.0.0/_version_meson.py',
+        'executable_bit-1.0.0/generate_version.py',
+    }
+    assert set(tar.name for tar in sdist.getmembers()) == expected
